@@ -2,6 +2,7 @@ import click
 from opnsense_cli.formatters.cli_output import CliOutputFormatter
 from opnsense_cli.callbacks.click import \
     formatter_from_formatter_name, bool_as_string, available_formats, int_as_string, tuple_to_csv
+from opnsense_cli.types.click_param_type.int_or_empty import INT_OR_EMPTY
 from opnsense_cli.commands.plugin.haproxy import haproxy
 from opnsense_cli.api.client import ApiClient
 from opnsense_cli.api.plugin.haproxy import Settings, Service
@@ -126,7 +127,7 @@ def show(haproxy_healthcheck_svc: HaproxyHealthcheckFacade, **kwargs):
     '--checkport',
     help=('Provide the TCP communication port to use during check, i.e. 80 or 443.'),
     show_default=True,
-    type=int,
+    type=INT_OR_EMPTY,
     callback=int_as_string,
     default=None,
     required=False,
@@ -256,7 +257,7 @@ def show(haproxy_healthcheck_svc: HaproxyHealthcheckFacade, **kwargs):
     '--agent_port',
     help=('Specify the TCP port used for agent checks.'),
     show_default=True,
-    type=int,
+    type=INT_OR_EMPTY,
     callback=int_as_string,
     default=None,
     required=False,
@@ -302,7 +303,7 @@ def show(haproxy_healthcheck_svc: HaproxyHealthcheckFacade, **kwargs):
     '--agentPort',
     help=('Enable agent checks'),
     show_default=True,
-    type=int,
+    type=INT_OR_EMPTY,
     callback=int_as_string,
     default=None,
     required=False,
@@ -425,7 +426,7 @@ def create(haproxy_healthcheck_svc: HaproxyHealthcheckFacade, **kwargs):
     '--checkport',
     help=('Provide the TCP communication port to use during check, i.e. 80 or 443.'),
     show_default=True,
-    type=int,
+    type=INT_OR_EMPTY,
     callback=int_as_string,
     default=None
 )
@@ -539,7 +540,7 @@ def create(haproxy_healthcheck_svc: HaproxyHealthcheckFacade, **kwargs):
     '--agent_port',
     help=('Specify the TCP port used for agent checks.'),
     show_default=True,
-    type=int,
+    type=INT_OR_EMPTY,
     callback=int_as_string,
     default=None
 )
@@ -579,7 +580,7 @@ def create(haproxy_healthcheck_svc: HaproxyHealthcheckFacade, **kwargs):
     '--agentPort',
     help=('Agent check port'),
     show_default=True,
-    type=int,
+    type=INT_OR_EMPTY,
     callback=int_as_string,
     default=None
 )
